graph_count

Function graph_count 

pub fn graph_count(n: usize, directed: bool) -> Result<usize>
The number of unlabeled simple graphs on n vertices (igraph_graph_count).

This is the number of isomorphism classes, i.e. the length of the histogram returned by Graph::motifs_randesu and one more than the largest valid Graph::isoclass. See OEIS A000088 (undirected) and A000273 (directed). Time complexity: O(1).

Binds igraph_graph_count.

Errors

ErrorKind::Overflow when the count does not fit in an i64 (n > 14 undirected, n > 9 directed, on 64-bit platforms).

Examples

use igraph::isomorphism::graph_count;
assert_eq!(graph_count(4, false).unwrap(), 11);
assert_eq!(graph_count(3, true).unwrap(), 16);