BlissInfo

Struct BlissInfo 

pub struct BlissInfo {
    pub nof_nodes: u64,
    pub nof_leaf_nodes: u64,
    pub nof_bad_nodes: u64,
    pub nof_canupdates: u64,
    pub nof_generators: u64,
    pub max_level: u64,
    pub group_size: String,
}
Statistics of a Bliss run (igraph_bliss_info_t).

Mostly useful to study the internal working of the algorithm, except for group_size, the exact size of the automorphism group, which may be astronomically large (e.g. n! for the complete graph K_n) and is therefore given as a decimal string.

Fields

nof_nodes: u64

Number of nodes in the search tree.

nof_leaf_nodes: u64

Number of leaf nodes in the search tree.

nof_bad_nodes: u64

Number of bad nodes.

nof_canupdates: u64

Number of canonical representative updates.

nof_generators: u64

Number of generators of the automorphism group.

max_level: u64

Maximum level of the search tree.

group_size: String

Size of the automorphism group, in base 10. It is empty when Bliss did not run to completion, e.g. in Graph::isomorphic_bliss when the two graphs have different vertex or edge counts.

Implementations

Source

impl BlissInfo

pub fn group_size_f64(&self) -> Option<f64>

The group size parsed as a float (possibly rounded, or infinite for huge groups); None if group_size is empty.

pub fn group_size_u128(&self) -> Option<u128>

The group size parsed as a u128; None if it is empty or too large.