pub struct IsoMapping {
pub map12: Vec<VertexId>,
pub map21: Vec<VertexId>,
}Expand description
An isomorphism (or subgraph isomorphism) between two graphs, as a pair of mutually inverse vertex maps.
For a full isomorphism both vectors are permutations. For a subgraph
isomorphism of graph2 into graph1, map21[v] is the vertex of
graph1 matched to vertex v of graph2, while map12[u] is the vertex
of graph2 matched to u, or -1 if u is not part of the match.
Fields
map12: Vec<VertexId>Maps each vertex of the first graph to a vertex of the second one.
map21: Vec<VertexId>Maps each vertex of the second graph to a vertex of the first one.