pub type CompatFn<'a> = Box<dyn FnMut(i64, i64) -> bool + 'a>;Expand description
A vertex or edge compatibility predicate for VF2: it receives the id of a vertex (edge) of the first graph and one of the second graph, and tells whether they may be matched.
Aliased Type
pub struct CompatFn<'a>(/* private fields */);